function vect = spacedvector(spacing, nPoints)
    % SPACEDVECTOR Returns a vector based on chosen spacing and number of points
    %
    % Spacing:
    %   - linear     : points spaced linearily
    %   - halfcosine : more dense at beginning and end of vector
    %   - cosine     : more dense at the beginning and more spaced out at the end
    %   - sine       : more dense at the end and more spaced out at the beginning
    %
    % -----
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % Apache 2.0 License
    % https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox

    % ----------------------------------------------------------------------------------------------

    switch spacing
        case 'linear'
            vect = linspace(0, 1, nPoints);
        case 'halfcosine'
            beta = linspace(0, pi, nPoints);
            vect = (1 - cos(beta)) / 2;
        case 'cosine'
            beta = linspace(0, pi / 2, nPoints);
            vect = 1 - cos(beta);
        case 'sine'
            beta = linspace(0, pi / 2, nPoints);
            vect = sin(beta);
    end

end
