% TEST_SANITIZESTRING Unitary tests for the sanitizestring sub-function
% Note:
%   Matlab package functionality is not very test-framework friendly.
%   Either the whole package has to be imported in EVERY SINGLE TEST or the
%   functions must be called as <package>.function() everytime.
%   The second option is preferred for the tests as it has the smaller scope.
%
% -----
% (c) Copyright 2022 University of Liege
% Author: Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% Apache 2.0 License
% https://gitlab.uliege.be/am-dept/matlab_airfoil_toolbox

% --------------------------------------------------------------------------------------------------

%% Main test function

function tests = test_sanitizestring

    tests = functiontests(localfunctions);

end

%% Setup and teardown

function setupOnce(testCase)

    addpath('../.'); % Add repository to Matlab Path
    addpath('./test_utils'); % Add utils to Matlab Path

    % Set random number generator settings
    testCase.TestData.currentRNG = rng;

end

function teardownOnce(testCase)

    rmpath('../.'); % Remove repository from Matlab Path
    rmpath('./test_utils'); % Remove utils from Matlab Path

    % Restore the random number generator settings
    s = testCase.TestData.currentRNG;
    rng(s);

end

function teardown(~)

    close all; % Close all figures that would have been openend

end

%% Test for correct output

function test_removeLeadingSpaces(testCase)
    % Leading spaces must be trimmed

    string = '   test';

    verifyEqual(testCase, af_tools.utils.sanitizestring(string), 'test');

end

function test_removeTrailingSpaces(testCase)
    % Trailing spaces must be trimmed

    string = 'test   ';

    verifyEqual(testCase, af_tools.utils.sanitizestring(string), 'test');

end

function test_replaceSingleSpaces(testCase)
    % Single spaces should be replaced by an underscore

    string = 'str1 str2  str3';

    verifyEqual(testCase, af_tools.utils.sanitizestring(string), 'str1_str2_str3');

end

function test_replaceMultiSpaces(testCase)
    % Multi spaces should be replaced by a single underscore

    string = 'str1    str2  str3';

    verifyEqual(testCase, af_tools.utils.sanitizestring(string), 'str1_str2_str3');

end

function test_replacePercent(testCase)
    % The % symbol should be replaced by 'pc'

    string = '0%';

    verifyEqual(testCase, af_tools.utils.sanitizestring(string), '0pc');

end
